# -*- coding: utf-8 -*-

"""Main module."""

import logging
from pathlib import Path

from docutils.core import publish_parts

logging.basicConfig(level=logging.DEBUG)
LOGGER = logging.getLogger("taika")


RST_PARSE_OPTIONS = {
    "tab_width": 4,
    "stylesheet_path": None,
    "doctitle_xform": False,
}


def run(source, dest):
    """Read all '\*.rst' files from `source`, parse them and write them back as HTML in `dest`."""
    source = Path(source)
    dest = Path(dest)

    for source_path in source.glob("**/*.rst"):
        source_path = Path(source_path)
        LOGGER.debug("Reading: %s", source_path)

        source_content = source_path.read_text()
        dest_content = parse_restructuredtext(source_content)

        dest_path = dest.joinpath(source_path.name).with_suffix(".html")
        LOGGER.debug("Writing: %s", dest_path)

        dest_path.parent.mkdir(parents=True, exist_ok=True)
        dest_path.touch()
        dest_path.write_text(dest_content)


def parse_restructuredtext(content):
    """Parse ReStructuredText from `content` and return it as HTML."""
    html = publish_parts(
        content, writer_name="html5", settings_overrides=RST_PARSE_OPTIONS
    )["whole"]

    return html



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    README = readme_file.read()

with open('HISTORY.rst') as history_file:
    HISTORY = history_file.read()

REQUIREMENTS = ["Click>=6.0", "docutils"]

SETUP_REQUIREMENTS = ['pytest-runner', ]

TEST_REQUIREMENTS = ['pytest', ]

setup(
    author="Hector Martinez-Lopez",
    author_email='hector.martinez.ub@gmail.com',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    description="Another Static Site Generator",
    entry_points={
        'console_scripts': [
            'taika=taika.cli:main',
        ],
    },
    install_requires=REQUIREMENTS,
    license="MIT license",
    long_description=README + '\n\n' + HISTORY,
    include_package_data=True,
    keywords='taika',
    name='taika',
    packages=find_packages(include=['taika']),
    setup_requires=SETUP_REQUIREMENTS,
    test_suite='tests',
    tests_require=TEST_REQUIREMENTS,
    url='https://gitlab.com/hectormartinez/taika',
    version='0.2.0',
    zip_safe=False,
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Tests for `taika` package."""

from pathlib import Path

from click.testing import CliRunner

from taika import cli, taika


def test_run():
    """Tests the function run in the taika module."""
    source = Path("test_source")
    dest = Path("test_dest")

    taika.run(source, dest)

    assert dest.is_dir()
    for path in source.glob("**/*.rst"):
        assert dest.joinpath(path.name).with_suffix(".html").is_file()

    dest.rmdir()


def test_command_line_interface():
    """Test the CLI."""
    runner = CliRunner()
    result = runner.invoke(cli.main)
    assert result.exit_code == 0
    assert 'taika.cli.main' in result.output
    help_result = runner.invoke(cli.main, ['--help'])
    assert help_result.exit_code == 0
    assert '--help  Show this message and exit.' in help_result.output
